==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/54/54360b6779b9b23cdcf3ca329fdc3557.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CampaignBundle/Executioner/TestInactiveExecutioner.php */
class __TwigTemplate_825ce6f4956a5ff17bc49047f1aad1b5 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CampaignBundle\\Executioner;

use Symfony\\Contracts\\Service\\ResetInterface;

/**
 * @internal Used in tests
 */
class TestInactiveExecutioner extends InactiveExecutioner implements ResetInterface
{
    /**
     * @internal Used in tests
     */
    public function setNowTime(\\DateTime \$dateTime): void
    {
        \$this->now = \$dateTime;
    }

    public function reset(): void
    {
        \$this->now = null;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CampaignBundle/Executioner/TestInactiveExecutioner.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CampaignBundle/Executioner/TestInactiveExecutioner.php", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Executioner/TestInactiveExecutioner.php");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/54/54360b6779b9b23cdcf3ca329fdc3557.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CampaignBundle/Executioner/TestInactiveExecutioner.php */
class __TwigTemplate_825ce6f4956a5ff17bc49047f1aad1b5 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CampaignBundle\\Executioner;

use Symfony\\Contracts\\Service\\ResetInterface;

/**
 * @internal Used in tests
 */
class TestInactiveExecutioner extends InactiveExecutioner implements ResetInterface
{
    /**
     * @internal Used in tests
     */
    public function setNowTime(\\DateTime \$dateTime): void
    {
        \$this->now = \$dateTime;
    }

    public function reset(): void
    {
        \$this->now = null;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CampaignBundle/Executioner/TestInactiveExecutioner.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CampaignBundle/Executioner/TestInactiveExecutioner.php", "/var/www/html/production-demo/app/bundles/CampaignBundle/Executioner/TestInactiveExecutioner.php");
    }
}
